Notification

Struct Notification 

pub struct Notification { /* private fields */ }
A SwiftBar notification that can be opened as a URL.

Implementations

Source

impl Notification

pub fn new(swiftbar: SwiftBar) -> Result<Self, PluginNameError>

Creates a new notification with default options.

Call methods on the returned instance to configure it.

pub fn title(self, title: impl ToString) -> Self

Sets the title for this notification.

pub fn subtitle(self, subtitle: impl ToString) -> Self

Sets the subtitle for this notification.

pub fn body(self, body: impl ToString) -> Self

Sets the text for this notification.

pub fn href(self, href: impl IntoUrl) -> Result<Self, ParseError>

Adds an URL that will be opened when this notification is clicked.

pub fn command<C: TryInto<Command>>( self, cmd: C, ) -> Result<Self, NotificationCommandError<C>>
where C::Error: Error,

Makes this notification run the given command when clicked.

pub fn silent(self) -> Self

Disables sound for this notification.

pub fn send(&self) -> Result<()>

Displays this notification.