pub struct Notification { /* private fields */ }Expand description
A SwiftBar notification that can be opened as a URL.
Implementations
Sourceimpl Notification
impl Notification
Sourcepub fn new(swiftbar: SwiftBar) -> Result<Self, PluginNameError>
pub fn new(swiftbar: SwiftBar) -> Result<Self, PluginNameError>
Creates a new notification with default options.
Call methods on the returned instance to configure it.
Sourcepub fn subtitle(self, subtitle: impl ToString) -> Self
pub fn subtitle(self, subtitle: impl ToString) -> Self
Sets the subtitle for this notification.
Sourcepub fn href(self, href: impl IntoUrl) -> Result<Self, ParseError>
pub fn href(self, href: impl IntoUrl) -> Result<Self, ParseError>
Adds an URL that will be opened when this notification is clicked.